@@ -5,10 +5,10 @@ suppressPackageStartupMessages(library(restatapi))
 options(restatapi_cores=1)
 
 
-# Function hicp.datasets() ------------------------------------------------
+# Function datasets() -----------------------------------------------------
 
 
-dt1 <- hicp.datasets()
+dt1 <- datasets()
 
 expect_equal(data.table::is.data.table(dt1), TRUE)
 expect_equal(nrow(dt1)>0, TRUE)
@@ -17,10 +17,11 @@ expect_equal(names(dt1), c("title","code","type","lastUpdate","lastModified","da
 Sys.sleep(1)
 
 
-# Function hicp.datafilters() ---------------------------------------------
+
+# Function datafilters() --------------------------------------------------
 
 
-dt2 <- hicp.datafilters(id="prc_hicp_inw")
+dt2 <- datafilters(id="prc_hicp_inw")
 
 expect_equal(data.table::is.data.table(dt2), TRUE)
 expect_equal(nrow(dt2)>0, TRUE)
@@ -29,10 +30,10 @@ expect_equal(names(dt2), c("concept","code","name"))
 Sys.sleep(1)
 
 
-# Function hicp.dataimport() ----------------------------------------------
+# Function data() ---------------------------------------------------------
 
 
-dt3 <- hicp.dataimport(id="prc_hicp_inw", filter=list("geo"="EA"), date.range=c("2020", NA))
+dt3 <- data(id="prc_hicp_inw", filter=list("geo"="EA"), date.range=c("2020", NA))
 
 expect_equal(data.table::is.data.table(dt3), TRUE)
 expect_equal(nrow(dt3)>0, TRUE)
